Data Coordination Platform Shared Library
=========================================

[![Build Status](https://travis-ci.org/HumanCellAtlas/dcplib.svg?branch=master)](https://travis-ci.org/HumanCellAtlas/dcplib)

The dcplib package contains modules shared across multiple DCP components.

## Installation

    pip install dcplib
   
## Testing

Run:

    make
